-----------------------------------------------------------------------
-- Collect ASCII Lines
-- 2017-10-12 Scannex
-- 2018-10-23 Use 'coro' library
--
-- Description:
--   Sleeps until the device COM port is powered
--   Collects lines of data and saves
--   Data that has no ending (after 500ms) is discarded
--
-- Configuration:
--   c.dev_baud = COM port baud rate
-----------------------------------------------------------------------

-- Write the Sample file header
function Header(tb,fh,nm)
 -- Put config + info tree at beginning of file
 fc.lv(fh, 'c,i', '\r\n')
end

-- Patch up the File-Table header and footer functions
ft={t=smp.t_md5,h=Header}

-- Woken up from deep sleep by device connecting
function onDevCon(na,ud,v)
 if dp:okr()
 then coro.add(GetData) -- Wake up to get data
 end
end

-- Called when config changes
function onConfig(na,ud,v)
 dp:set(c.dev_baud or '19200n8')
end

rxua={es='\n'} -- Looking for LF (i.e. CRLF or LF)

-- Get a line of data and save it
function RX()
 local txt,b,ti,fs = dp:rxu(rxua, 500) -- Get line with 0.5s timeout
 if fs==0
 then return false -- didn't find any ending
 end
 smp.save(txt)
 return true
end

-- Handle data while COM connected + powered
function COM()
 if dp:rxw() <= 0
 then
  rt.ms(250)
  return
 end
 fc.cache(2) -- Speed up file writing
 usb.log('app', 'Data')
 while RX() and rt.dorun()
 do
   -- Work
 end
 fc.cache(0) -- Turn off file caching
 smp.close() -- Release the sample store file
 usb.log('app', 'stop')
end

-- Grab data from the Device port
function GetData()
  usb.log('app', 'Awake')    
  dp:pwrx(true) -- want to receive data
  while rt.dorun() do
   COM()
   if not dp:okr()
   then
    usb.log('app', 'Waiting')
    dp:pwrx(false) -- low power
    return
   end
  end
end

-- Setup
function Setup()
  dp:rxto(10)
  dp:txf(0)
  dp:rxf(0) -- NOTE: If you enable RX flow control this stops low-power mode (because must assert RTS!)
  dp:fifo(8192)
end

dp = ser.dev()     -- The device COM port
evt.en('onDevCon') -- Enable event
Setup()
