-----------------------------------------------------------------------
-- Pressure and Pulse Count sample app
-- 2017-06-26 Scannex
-- 2018-10-23 Use 'coro' library
--
-- Description:
--   Uses Job1 to set sampling rate
--   Performs +/- tally on pulse counts
--
-- Configuration:
--   c.ppc_job = job string for sampling (default 00:01:00)
--   c.adc_m = ADC scale (default 1)
--   c.adc_c = ADC offset (default 0)
-----------------------------------------------------------------------

pt = 0 -- Tally

-- Write the Sample file header
function Header(tb,fh,nm)
 -- Put config + info tree at beginning of file
 fc.lv(fh, 'c,i', '\r\n')
end

-- Patch up the File-Table header and footer functions
ft={t=smp.t_md5,h=Header}

-- The main App loop
function Sample()
 local p1,p2=dpc.rst() -- Take a pulse count reading
 pt = pt+p1-p2 -- Work out the +/- tally   
 local pv = rt.adc(c.adc_m or 1, c.adc_c or 0) -- Take an ADC reading
 local t = {p1,p2,pt,pv} -- Put together in a table
 i.app.t = t -- Save the table for reference
 smp.save( smp.csv(t) ) -- Convert to CSV and save
end

-- Event for sampling
function onJob1()
 coro.add(Sample) -- Put the function on the queue
end

-- Configuration changed
function onConfig()
 job.set(1, c.ppc_job or '00:01')
end

